#!/usr/bin/env python3
# encoding: utf-8
#
# Copyright (C) 2020 Timm Fitschen <t.fitschen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
#
"""
Reject a return request.
"""
from __future__ import absolute_import

import caosdb as db
from caosadvancedtools.serverside.helper import print_success

from .box_loan import (F_LOAN, RETURN_REQUESTED, S_LENT, S_RETURN_REQUESTED, get_borrower_names,
                       get_loan, main, update_loan_state)


def _reject_return_request(loan):
    """Update a `Loan` Record and remove the `returnRequested` Property."""

    # This changes the state from "return_requested" back to "lent".
    update_loan_state(loan, S_LENT)

    loan.update()


def reject_return_request(data):
    """Reject a return request.

    I.e. update the `Loan` Record and remove the `returnRequested` Property.
    """
    loan = get_loan(data[F_LOAN])
    _reject_return_request(loan)
    fn, ln = get_borrower_names(loan)

    print_success('You rejected return request by {fn} {ln}. See '
                  '<a href="{loan}" title="Go to the loan record.">'
                  'here</a>'.format(fn=fn, ln=ln, loan=loan.id))
    return 0


if __name__ == "__main__":
    main(reject_return_request)
